==> fawry_sdk-0.0.1.tar.gz: lib/model/fawry_launch_model.dart <==
import 'package:fawry_sdk/model/payment_methods.dart';

import 'bill_item.dart';
import 'launch_customer_model.dart';
import 'launch_merchant_model.dart';

class FawryLaunchModel {
  bool allow3DPayment;
  bool allowMockData;
  String? beid;
  String? branchCode;
  String? branchName;
  List<BillItem>? chargeItems;
  LaunchCustomerModel? launchCustomerModel;
  LaunchMerchantModel? launchMerchantModel;
  PaymentMethods? paymentMethods;
  DateTime? scheduledTime;
  String secretCode;
  String serviceTypeCode;
  String? shippingAddress;
  bool skipLogin;
  bool skipReceipt;
  bool skipCustomerInput;
  String? signature;
  
  FawryLaunchModel(
      this.allow3DPayment,
      this.allowMockData,
      this.beid,
      this.branchCode,
      this.branchName,
      this.chargeItems,
      this.launchCustomerModel,
      this.launchMerchantModel,
      this.paymentMethods,
      this.scheduledTime,
      this.secretCode,
      this.serviceTypeCode,
      this.shippingAddress,
      this.skipLogin,
      this.skipReceipt,
      this.skipCustomerInput,
      this.signature);

  Map<String, dynamic> toJson() {
    List<Map>? chargeItems = this.chargeItems?.map((i) => i.toJson()).toList();
    Map? launchCustomerModel = this.launchCustomerModel?.toJson();
    Map? launchMerchantModel = this.launchMerchantModel?.toJson();

    return {
      'allow3DPayment': allow3DPayment,
      'allowMockData': allowMockData,
      'beid': beid,
      'branchCode': branchCode,
      'chargeItems': chargeItems,
      'launchCustomerModel': launchCustomerModel,
      'launchMerchantModel': launchMerchantModel,
      'paymentMethods': paymentMethods,
      'scheduledTime': scheduledTime?.toIso8601String(),
      'secretCode': secretCode,
      'secureKey' : secretCode,
      'serviceTypeCode': serviceTypeCode,
      'shippingAddress': shippingAddress,
      'skipLogin': skipLogin,
      'skipReceipt': skipReceipt,
      'skipCustomerInput' : skipCustomerInput,
      'merchant': launchMerchantModel,
      'customer': launchCustomerModel,
      "signature": signature
    };
  }
}

==> fawry_sdk-0.0.4.tar.gz: lib/model/fawry_launch_model.dart <==
import 'package:fawry_sdk/model/payment_methods.dart';

import 'bill_item.dart';
import 'launch_customer_model.dart';
import 'launch_merchant_model.dart';

class FawryLaunchModel {
  bool allow3DPayment;
  bool allowMockData;
  String? beid;
  String? branchCode;
  String? branchName;
  List<BillItem>? chargeItems;
  LaunchCustomerModel? launchCustomerModel;
  LaunchMerchantModel? launchMerchantModel;
  PaymentMethods? paymentMethods;
  DateTime? scheduledTime;
  String serviceTypeCode;
  String? shippingAddress;
  bool skipLogin;
  bool skipReceipt;
  bool skipCustomerInput;
  String? signature;

  FawryLaunchModel(
      {required this.allow3DPayment,
      required this.allowMockData,
      this.beid,
      this.branchCode,
      this.branchName,
      this.chargeItems,
      this.launchCustomerModel,
      this.launchMerchantModel,
      this.paymentMethods,
      this.scheduledTime,
      required this.serviceTypeCode,
      this.shippingAddress,
      required this.skipLogin,
      required this.skipReceipt,
      required this.skipCustomerInput,
      this.signature});

  Map<String, dynamic> toJson() {
    List<Map>? chargeItems = this.chargeItems?.map((i) => i.toJson()).toList();
    Map? launchCustomerModel = this.launchCustomerModel?.toJson();
    Map? launchMerchantModel = this.launchMerchantModel?.toJson();

    return {
      'allow3DPayment': allow3DPayment,
      'allowMockData': allowMockData,
      'beid': beid,
      'branchCode': branchCode,
      'chargeItems': chargeItems,
      'launchCustomerModel': launchCustomerModel,
      'launchMerchantModel': launchMerchantModel,
      'paymentMethods': paymentMethods,
      'scheduledTime': scheduledTime?.toIso8601String(),
      'serviceTypeCode': serviceTypeCode,
      'shippingAddress': shippingAddress,
      'skipLogin': skipLogin,
      'skipReceipt': skipReceipt,
      'skipCustomerInput': skipCustomerInput,
      'merchant': launchMerchantModel,
      'customer': launchCustomerModel,
      "signature": signature
    };
  }
}
